@@ -1,4 +1,4 @@
-use axum::{handler::get, Router};
+use axum::{routing::get, Router};
 use std::net::SocketAddr;
 use tower_cookies::{Cookie, CookieManagerLayer, Cookies};
 
